==> bytedesk_kefu-0.1.2.tar.gz: lib/http/bytedesk_leavemsg_api.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:bytedesk_kefu/model/helpCategory.dart';
import 'package:bytedesk_kefu/model/jsonResult.dart';
import 'package:bytedesk_kefu/util/bytedesk_constants.dart';
import 'package:flustars/flustars.dart';
import 'package:http/http.dart' as http;

class BytedeskLeaveMsgHttpApi {
  //
  static const uid = BytedeskConstants.HELP_CATEGORY_UID;
  static const client = BytedeskConstants.client;
  static String baseUrl = Platform.isAndroid
      ? BytedeskConstants.httpBaseUrlAndroid
      : BytedeskConstants.httpBaseUrliOS;

  final http.Client httpClient = http.Client();

  BytedeskLeaveMsgHttpApi();
  //

  // 获取意见反馈分类
  Future<List<HelpCategory>> getHelpLeaveMsgCategories() async {
    //
    final categoriesUrl =
        '$baseUrl/visitor/api/category/feedback?uid=$uid&client=$client';
    print("categories Url $categoriesUrl");
    final initResponse = await this.httpClient.get(categoriesUrl);
    //
    //解决json解析中的乱码问题
    Utf8Decoder utf8decoder = Utf8Decoder(); // fix 中文乱码
    //将string类型数据 转换为json类型的数据
    final responseJson =
        json.decode(utf8decoder.convert(initResponse.bodyBytes));
    //
    List<HelpCategory> categories = (responseJson['data'] as List<dynamic>)
        .map((item) => HelpCategory.fromJson(item))
        .toList();

    return categories;
  }

  // TODO: 提交意见反馈
  Future<JsonResult> submitLeaveMsg(
      String content, List<String> imageUrls) async {
    //
    String accessToken = SpUtil.getString(BytedeskConstants.accessToken);
    Map<String, String> headers = {
      HttpHeaders.contentTypeHeader: "application/json",
      HttpHeaders.authorizationHeader: "Bearer $accessToken"
    };
    //
    var body = json.encode({"content": content, "client": "flutter"});
    //
    final initUrl = '$baseUrl/api/feedback/create';
    final initResponse =
        await this.httpClient.post(initUrl, headers: headers, body: body);
    //解决json解析中的乱码问题
    Utf8Decoder utf8decoder = Utf8Decoder(); // fix 中文乱码
    //将string类型数据 转换为json类型的数据
    final responseJson =
        json.decode(utf8decoder.convert(initResponse.bodyBytes));
    print("responseJson $responseJson");
    // TODO: 更新本地数据

    // return User.fromJson(responseJson);
    return JsonResult();
  }

  // https://pub.dev/documentation/http/latest/http/MultipartRequest-class.html
  Future<String> upload(String filePath) async {
    //
    String fileName = filePath.split("/").last;
    String username = SpUtil.getString(BytedeskConstants.uid);

    final uploadUrl = '$baseUrl/visitor/api/upload/image';
    print("fileName $fileName, username $username, upload Url $uploadUrl");

    var uri = Uri.parse(uploadUrl);
    var request = http.MultipartRequest('POST', uri)
      ..fields['file_name'] = fileName
      ..fields['username'] = username
      ..files.add(await http.MultipartFile.fromPath('file', filePath));

    http.Response response =
        await http.Response.fromStream(await request.send());
    // print("Result: ${response.body}");

    //解决json解析中的乱码问题
    Utf8Decoder utf8decoder = Utf8Decoder(); // fix 中文乱码
    //将string类型数据 转换为json类型的数据
    final responseJson = json.decode(utf8decoder.convert(response.bodyBytes));
    print("responseJson $responseJson");

    String url = responseJson['data'];
    print('url:' + url);
    return url;
  }


}

==> bytedesk_kefu-0.1.5.tar.gz: lib/http/bytedesk_leavemsg_api.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:bytedesk_kefu/model/helpCategory.dart';
import 'package:bytedesk_kefu/model/jsonResult.dart';
import 'package:bytedesk_kefu/util/bytedesk_constants.dart';
import 'package:flustars/flustars.dart';
import 'package:http/http.dart' as http;

class BytedeskLeaveMsgHttpApi {
  //
  static const uid = BytedeskConstants.HELP_CATEGORY_UID;
  static const client = BytedeskConstants.client;
  static String baseUrl = Platform.isAndroid
      ? BytedeskConstants.httpBaseUrlAndroid
      : BytedeskConstants.httpBaseUrliOS;

  final http.Client httpClient = http.Client();

  BytedeskLeaveMsgHttpApi();
  //

  // 获取意见反馈分类
  Future<List<HelpCategory>> getHelpLeaveMsgCategories() async {
    //
    final categoriesUrl =
        '$baseUrl/visitor/api/category/feedback?uid=$uid&client=$client';
    print("categories Url $categoriesUrl");
    final initResponse = await this.httpClient.get(categoriesUrl);
    //
    //解决json解析中的乱码问题
    Utf8Decoder utf8decoder = Utf8Decoder(); // fix 中文乱码
    //将string类型数据 转换为json类型的数据
    final responseJson =
        json.decode(utf8decoder.convert(initResponse.bodyBytes));
    //
    List<HelpCategory> categories = (responseJson['data'] as List<dynamic>)
        .map((item) => HelpCategory.fromJson(item))
        .toList();

    return categories;
  }

  // TODO: 提交意见反馈
  Future<JsonResult> submitLeaveMsg(
      String content, List<String> imageUrls) async {
    //
    String accessToken = SpUtil.getString(BytedeskConstants.accessToken);
    Map<String, String> headers = {
      HttpHeaders.contentTypeHeader: "application/json",
      HttpHeaders.authorizationHeader: "Bearer $accessToken"
    };
    //
    var body = json.encode({"content": content, "client": client});
    //
    final initUrl = '$baseUrl/api/feedback/create';
    final initResponse =
        await this.httpClient.post(initUrl, headers: headers, body: body);
    //解决json解析中的乱码问题
    Utf8Decoder utf8decoder = Utf8Decoder(); // fix 中文乱码
    //将string类型数据 转换为json类型的数据
    final responseJson =
        json.decode(utf8decoder.convert(initResponse.bodyBytes));
    print("responseJson $responseJson");
    // TODO: 更新本地数据

    // return User.fromJson(responseJson);
    return JsonResult();
  }

  // https://pub.dev/documentation/http/latest/http/MultipartRequest-class.html
  Future<String> upload(String filePath) async {
    //
    String fileName = filePath.split("/").last;
    String username = SpUtil.getString(BytedeskConstants.uid);

    final uploadUrl = '$baseUrl/visitor/api/upload/image';
    print("fileName $fileName, username $username, upload Url $uploadUrl");

    var uri = Uri.parse(uploadUrl);
    var request = http.MultipartRequest('POST', uri)
      ..fields['file_name'] = fileName
      ..fields['username'] = username
      ..files.add(await http.MultipartFile.fromPath('file', filePath));

    http.Response response =
        await http.Response.fromStream(await request.send());
    // print("Result: ${response.body}");

    //解决json解析中的乱码问题
    Utf8Decoder utf8decoder = Utf8Decoder(); // fix 中文乱码
    //将string类型数据 转换为json类型的数据
    final responseJson = json.decode(utf8decoder.convert(response.bodyBytes));
    print("responseJson $responseJson");

    String url = responseJson['data'];
    print('url:' + url);
    return url;
  }


}
